==> dart_6.9.5.orig.tar.xz: dart-6.9.5/dart/dynamics/detail/EntityNodeAspect.hpp <==
/*
 * Copyright (c) 2011-2019, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_
#define DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_

#include "dart/dynamics/Node.hpp"

namespace dart {
namespace dynamics {

template <class Base>
class EntityNode;

namespace detail {

//==============================================================================
struct EntityNodeProperties
{
  /// Name of the Entity/Node
  std::string mName;

  /// Default constructor
  EntityNodeProperties(const std::string& name = "");

  /// Implicit conversion to a string
  operator const std::string&() const;
};

//==============================================================================
template <class Base>
using EntityNodeAspectBase =
    common::EmbedProperties<EntityNode<Base>, EntityNodeProperties>;

//==============================================================================
template <class Base, bool isCompositeBase>
class EntityNodeBase : public Base, public EntityNodeAspectBase<Base>
{
public:

  /// Forwarding constructor
  template <typename... Args>
  EntityNodeBase(Args&&... args)
    : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  virtual ~EntityNodeBase() = default;
};

//==============================================================================
template <class Base>
class EntityNodeBase<Base, true> : public common::CompositeJoiner<
    EntityNodeAspectBase<Base>, Base >
{
public:

  /// Forwarding constructor
  template <typename... Args>
  EntityNodeBase(Args&&... args)
    : common::CompositeJoiner<Base, EntityNodeAspectBase<Base>>(
        common::NoArg, std::forward<Args>(args)...)
  {
    // Do nothing
  }

  virtual ~EntityNodeBase() = default;
};

} // namespace detail
} // namespace dart
} // namespace dynamics

#endif // DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_

==> dart_6.12.1+dfsg4.orig.tar.xz: dart-6.12.1/dart/dynamics/detail/EntityNodeAspect.hpp <==
/*
 * Copyright (c) 2011-2021, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_
#define DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_

#include "dart/dynamics/Node.hpp"

namespace dart {
namespace dynamics {

template <class Base>
class EntityNode;

namespace detail {

//==============================================================================
struct EntityNodeProperties
{
  /// Name of the Entity/Node
  std::string mName;

  /// Default constructor
  EntityNodeProperties(const std::string& name = "");

  /// Implicit conversion to a string
  operator const std::string&() const;
};

//==============================================================================
template <class Base>
using EntityNodeAspectBase
    = common::EmbedProperties<EntityNode<Base>, EntityNodeProperties>;

//==============================================================================
template <class Base, bool isCompositeBase>
class EntityNodeBase : public Base, public EntityNodeAspectBase<Base>
{
public:
  /// Forwarding constructor
  template <typename... Args>
  EntityNodeBase(Args&&... args) : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  virtual ~EntityNodeBase() = default;
};

//==============================================================================
template <class Base>
class EntityNodeBase<Base, true>
  : public common::CompositeJoiner<EntityNodeAspectBase<Base>, Base>
{
public:
  /// Forwarding constructor
  template <typename... Args>
  EntityNodeBase(Args&&... args)
    : common::CompositeJoiner<Base, EntityNodeAspectBase<Base>>(
        common::NoArg, std::forward<Args>(args)...)
  {
    // Do nothing
  }

  virtual ~EntityNodeBase() = default;
};

} // namespace detail
} // namespace dynamics
} // namespace dart

#endif // DART_DYNAMICS_DETAIL_ENTITYNODEASPECT_HPP_
